@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -30,6 +31,10 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
+
 #ifndef YY_YY_DEXPR_PARSER_H_INCLUDED
 # define YY_YY_DEXPR_PARSER_H_INCLUDED
 /* Debug traces.  */
@@ -40,29 +45,38 @@
 extern int yydebug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    TOK_EQ = 258,
-    TOK_NE = 259,
-    TOK_LT = 260,
-    TOK_LE = 261,
-    TOK_GT = 262,
-    TOK_GE = 263,
-    TOK_SPEC = 264,
-    TOK_STRING = 265,
-    TOK_DATETIME = 266,
-    TOK_INT = 267,
-    TOK_OR = 268,
-    TOK_AND = 269,
-    TOK_NOT = 270,
-    TOK_LPAREN = 271,
-    TOK_RPAREN = 272
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    TOK_EQ = 258,                  /* TOK_EQ  */
+    TOK_NE = 259,                  /* TOK_NE  */
+    TOK_LT = 260,                  /* TOK_LT  */
+    TOK_LE = 261,                  /* TOK_LE  */
+    TOK_GT = 262,                  /* TOK_GT  */
+    TOK_GE = 263,                  /* TOK_GE  */
+    TOK_SPEC = 264,                /* TOK_SPEC  */
+    TOK_STRING = 265,              /* TOK_STRING  */
+    TOK_DATETIME = 266,            /* TOK_DATETIME  */
+    TOK_INT = 267,                 /* TOK_INT  */
+    TOK_OR = 268,                  /* TOK_OR  */
+    TOK_AND = 269,                 /* TOK_AND  */
+    TOK_NOT = 270,                 /* TOK_NOT  */
+    TOK_LPAREN = 271,              /* TOK_LPAREN  */
+    TOK_RPAREN = 272               /* TOK_RPAREN  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define YYEMPTY -2
+#define YYEOF 0
+#define YYerror 256
+#define YYUNDEF 257
 #define TOK_EQ 258
 #define TOK_NE 259
 #define TOK_LT 260
@@ -81,17 +95,16 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 85 "dexpr-parser.y" /* yacc.c:1909  */
+#line 85 "dexpr-parser.y"
 
 	dexpr_t dex;
 	char *sval;
 
-#line 93 "dexpr-parser.h" /* yacc.c:1909  */
-};
+#line 106 "dexpr-parser.h"
 
+};
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
@@ -99,6 +112,8 @@ typedef union YYSTYPE YYSTYPE;
 
 
 
+
 int yyparse (dexpr_t *cur);
 
+
 #endif /* !YY_YY_DEXPR_PARSER_H_INCLUDED  */
